Test Report

# Summary

Started | 2025-06-02 18:16:39
Ended | 2025-06-02 18:25:42
Duration | 0:09:02.690189
Total run time | 0:08:44.762991

100 passed 5 skipped

# Warnings

## Warnings 190

- DeprecationWarning Please import `gaussian_filter1d` from the `scipy.ndimage` namespace; the `scipy.ndimage.filters` namespace is deprecated and will be removed in SciPy 2.0.0.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/isofit/utils/instrument_model.py:25
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=166) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.739203

### PASSED Test_CLIParser::test_json_opts 0:00:00.192992

Started | 2025-06-02 18:16:53
Ended | 2025-06-02 18:16:53
Duration | 0:00:00.192992
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.122464

Started | 2025-06-02 18:16:53
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.122464
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.082335

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.082335
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.129391

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.129391
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.046895

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.046895
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.081809

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.081809
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.083316

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.083316
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.363067

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.008650

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.008650
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.017909

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.017909
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.037181

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.037181
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043765

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.043765
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.034196

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.034196
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.033874

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.033874
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.016732

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.016732
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.016428

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.016428
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.024923

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.024923
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.016143

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.016143
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.034193

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.034193
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.043793

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.043793
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.035280

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:16:54
Duration | 0:00:00.035280
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:02.304514

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.697380

Started | 2025-06-02 18:16:54
Ended | 2025-06-02 18:17:03
Duration | 0:00:08.697380
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpdwp18bnj'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 18:16:55:   Reading metadata for VNIR detector...
    2025/06/02 18:16:55:   Calculating solar irradiance...
    2025/06/02 18:16:55:   Reading metadata for SWIR detector...
    2025/06/02 18:16:56:   Calculating solar irradiance...
    2025/06/02 18:16:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:16:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:16:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:16:56:   Reading metadata for VNIR detector...
    2025/06/02 18:16:56:   Calculating solar irradiance...
    2025/06/02 18:16:56:   Reading metadata for SWIR detector...
    2025/06/02 18:16:56:   Calculating solar irradiance...
    2025/06/02 18:16:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:16:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:16:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:16:57:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:16:57:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:16:57:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:16:57:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:16:57:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:16:58:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:16:58:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/06/02 18:16:58:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 18:16:58:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/06/02 18:16:58:   Starting orthorectification...
    2025/06/02 18:16:58:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/06/02 18:16:58:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:16:59:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:17:01:   Merging VNIR and SWIR data...
    2025/06/02 18:17:01:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:17:01:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:17:01:   Generating L2A metadata...
    2025/06/02 18:17:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:17:03:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/06/02 18:17:03:   L2A product successfully written!
    2025/06/02 18:17:03:   Total runtime of the processing chain: 0:00:08.631657

##### Captured stderr call

    2025/06/02 18:16:57:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:16:57:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:16:57:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:16:57:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:16:57:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:17:03:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 18:17:03:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:17:03:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:56.750716

Started | 2025-06-02 18:17:03
Ended | 2025-06-02 18:18:00
Duration | 0:00:56.750716
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpdmjtl6yu'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 18:17:03:   Reading metadata for VNIR detector...
    2025/06/02 18:17:04:   Calculating solar irradiance...
    2025/06/02 18:17:04:   Reading metadata for SWIR detector...
    2025/06/02 18:17:04:   Calculating solar irradiance...
    2025/06/02 18:17:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:17:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:17:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:17:05:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:17:05:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:17:06:   Computing VNIR geolayer...
    2025/06/02 18:17:06:   Computing SWIR geolayer...
    2025/06/02 18:17:06:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 18:17:07:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 18:17:07:   Preparing reference image for co-registration.
    2025/06/02 18:17:07:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 18:17:18:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.16s
    2025/06/02 18:17:18:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 18:17:19:   Applying results of spatial optimization to geolayer.
    2025/06/02 18:17:19:   Pre-processing DEM for VNIR...
    2025/06/02 18:17:19:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 18:17:19:   Pre-processing DEM for SWIR...
    2025/06/02 18:17:19:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 18:17:19:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 18:17:20:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 18:17:20:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 18:17:20:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 18:17:20:   Setting up forward operator...
    2025/06/02 18:17:20:   SICOR is applied to land AND water pixels.
    2025/06/02 18:17:20:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 18:17:21:   Getting observation metadata...
    2025/06/02 18:17:21:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 18:17:21:   Loading solar irradiance model...
    2025/06/02 18:17:21:   Loading RT LUT...
    2025/06/02 18:17:21:   LUT file was properly downloaded and is available for AC!
    2025/06/02 18:17:22:   Converting LUT to Fontenla solar model...
    2025/06/02 18:17:22:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 18:17:43:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 18:17:43:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 18:17:43:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 18:17:45:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 18:17:45:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 18:17:45:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 18:17:45:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 18:17:45:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 18:17:45:   Preparing segmented SWIR L1B data cube...
    2025/06/02 18:17:46:   Performing 3 phases of water retrieval...
    2025/06/02 18:17:46:   Setting up multiprocessing...
    2025/06/02 18:17:46:   Multiprocessing on 24 cpu's
    2025/06/02 18:17:46:   Preparing optimal estimation input...
    2025/06/02 18:17:46:   Optimization...
    2025/06/02 18:17:48:   Done!
    2025/06/02 18:17:48:   Runtime: 2.28 s
    2025/06/02 18:17:48:   Smoothing segmented CWV retrieval map...
    2025/06/02 18:17:48:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 18:17:49:   Starting surface reflectance retrieval...
    2025/06/02 18:17:49:   Calculating surface reflectance for vnir detector...
    2025/06/02 18:17:51:   Calculating surface reflectance for swir detector...
    2025/06/02 18:17:54:   Smoothing segmented liquid water and ice maps...
    2025/06/02 18:17:55:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 18:17:55:   Joining results of atmospheric correction.
    2025/06/02 18:17:55:   Starting orthorectification...
    2025/06/02 18:17:55:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/06/02 18:17:55:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:17:56:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:17:57:   Merging VNIR and SWIR data...
    2025/06/02 18:17:57:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:17:57:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:17:57:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:17:57:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:17:57:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:17:58:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:17:58:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:17:58:   Generating L2A metadata...
    2025/06/02 18:17:59:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 18:18:00:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 18:18:00:   L2A product successfully written!
    2025/06/02 18:18:00:   Total runtime of the processing chain: 0:00:56.687050

##### Captured stderr call

    2025/06/02 18:17:03:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 18:17:06:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.4% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.4% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.2% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.7% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.3% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.3% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.6% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.2% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.2% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.5% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.5% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.4% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.4% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.2% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.1% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.1% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.2% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:09
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:09
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:09
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:09
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:09
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:09
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:09
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:10
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:10
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:10
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:10
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:10
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:10
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 2.7% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.3% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 8.9% Complete  => 0:00:00
    	progress: |==========----------------------------------------| 20.0% Complete  => 0:00:00
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:00
    	progress: |====================------------------------------| 40.0% Complete  => 0:00:00
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:01
    	progress: |======================================------------| 76.4% Complete  => 0:00:01
    	progress: |============================================------| 87.1% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 18:17:54:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:17:54:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:18:00:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 18:18:00:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:18:00:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:18:00:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.039340

Started | 2025-06-02 18:18:00
Ended | 2025-06-02 18:18:00
Duration | 0:00:00.039340
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:19.535925

Started | 2025-06-02 18:18:00
Ended | 2025-06-02 18:19:19
Duration | 0:01:19.535925
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmp7hrdi_2p'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 18:18:00:   Reading metadata for VNIR detector...
    2025/06/02 18:18:00:   Calculating solar irradiance...
    2025/06/02 18:18:00:   Reading metadata for SWIR detector...
    2025/06/02 18:18:01:   Calculating solar irradiance...
    2025/06/02 18:18:01:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:18:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:18:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:18:01:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:18:01:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:18:01:   Computing VNIR geolayer...
    2025/06/02 18:18:01:   Computing SWIR geolayer...
    2025/06/02 18:18:01:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:18:01:   Percentage of defective pixels: 0.49
    2025/06/02 18:18:01:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 18:18:02:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:18:02:   Percentage of defective pixels: 0.50
    2025/06/02 18:18:02:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 18:18:02:   Pre-processing DEM for VNIR...
    2025/06/02 18:18:02:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 18:18:02:   Pre-processing DEM for SWIR...
    2025/06/02 18:18:02:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 18:18:02:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 18:18:02:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 18:18:02:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 18:18:02:   Setting up forward operator...
    2025/06/02 18:18:02:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/06/02 18:18:03:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 18:18:03:   Getting observation metadata...
    2025/06/02 18:18:03:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 18:18:03:   Loading solar irradiance model...
    2025/06/02 18:18:03:   Loading RT LUT...
    2025/06/02 18:18:03:   LUT file was properly downloaded and is available for AC!
    2025/06/02 18:18:04:   Converting LUT to Fontenla solar model...
    2025/06/02 18:18:04:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 18:18:23:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 18:18:23:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 18:18:23:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 18:18:24:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 18:18:25:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 18:18:25:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 18:18:25:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 18:18:25:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 18:18:25:   Preparing segmented SWIR L1B data cube...
    2025/06/02 18:18:25:   Performing 3 phases of water retrieval...
    2025/06/02 18:18:25:   Setting up multiprocessing...
    2025/06/02 18:18:25:   Multiprocessing on 16 cpu's
    2025/06/02 18:18:25:   Preparing optimal estimation input...
    2025/06/02 18:18:25:   Optimization...
    2025/06/02 18:18:26:   Done!
    2025/06/02 18:18:26:   Runtime: 1.45 s
    2025/06/02 18:18:26:   Smoothing segmented CWV retrieval map...
    2025/06/02 18:18:26:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 18:18:27:   Starting surface reflectance retrieval...
    2025/06/02 18:18:27:   Calculating surface reflectance for vnir detector...
    2025/06/02 18:18:28:   Calculating surface reflectance for swir detector...
    2025/06/02 18:18:30:   Smoothing segmented liquid water and ice maps...
    2025/06/02 18:18:30:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/06/02 18:18:30:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/06/02 18:18:30:   Landmask is EnMAP L1B
    Starting processing at 2025-06-02 18:18:30.398077
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:44.838935
    2025/06/02 18:19:15:   Joining results of atmospheric correction.
    2025/06/02 18:19:15:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 18:19:15:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:15:   Percentage of defective pixels: 0.49
    2025/06/02 18:19:15:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 18:19:15:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:15:   Percentage of defective pixels: 0.50
    2025/06/02 18:19:15:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 18:19:15:   Starting orthorectification...
    2025/06/02 18:19:15:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 18:19:15:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:19:16:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:19:16:   Merging VNIR and SWIR data...
    2025/06/02 18:19:16:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:19:16:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'polymer_logchl' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'polymer_logfb' attribute...
    2025/06/02 18:19:17:   Orthorectifying 'polymer_rgli' attribute...
    2025/06/02 18:19:18:   Orthorectifying 'polymer_rnir' attribute...
    2025/06/02 18:19:18:   Orthorectifying 'polymer_bitmask' attribute...
    2025/06/02 18:19:18:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:19:18:   Generating L2A metadata...
    2025/06/02 18:19:19:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/06/02 18:19:19:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 18:19:19:   L2A product successfully written!
    2025/06/02 18:19:19:   Total runtime of the processing chain: 0:01:19.467130

##### Captured stderr call

    2025/06/02 18:18:00:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 7.3% Complete  => 0:00:00
    	progress: |=====================-----------------------------| 41.5% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/06/02 18:18:30:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:18:30:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:19:19:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 18:19:19:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:19:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:19:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:37.281153

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-06-02 18:19:19
Ended | 2025-06-02 18:19:57
Duration | 0:00:37.281153
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpsnr_m61u'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/06/02 18:19:20:   Reading metadata for VNIR detector...
    2025/06/02 18:19:20:   Calculating solar irradiance...
    2025/06/02 18:19:20:   Reading metadata for SWIR detector...
    2025/06/02 18:19:20:   Calculating solar irradiance...
    2025/06/02 18:19:20:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:19:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:19:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:19:20:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:19:21:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:19:21:   Computing VNIR geolayer...
    2025/06/02 18:19:21:   Computing SWIR geolayer...
    2025/06/02 18:19:21:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:21:   Percentage of defective pixels: 0.49
    2025/06/02 18:19:21:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 18:19:21:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:21:   Percentage of defective pixels: 0.50
    2025/06/02 18:19:21:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 18:19:21:   Pre-processing DEM for VNIR...
    2025/06/02 18:19:21:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/06/02 18:19:21:   Pre-processing DEM for SWIR...
    2025/06/02 18:19:21:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/06/02 18:19:21:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/06/02 18:19:22:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/06/02 18:19:22:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/06/02 18:19:22:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/06/02 18:19:22:   Setting up forward operator...
    2025/06/02 18:19:22:   SICOR is applied to land AND water pixels.
    2025/06/02 18:19:22:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/06/02 18:19:23:   Getting observation metadata...
    2025/06/02 18:19:23:   Checking if observation metadata values are within LUT value ranges...
    2025/06/02 18:19:23:   Loading solar irradiance model...
    2025/06/02 18:19:23:   Loading RT LUT...
    2025/06/02 18:19:23:   LUT file was properly downloaded and is available for AC!
    2025/06/02 18:19:23:   Converting LUT to Fontenla solar model...
    2025/06/02 18:19:23:   Resampling LUT to EnMAP wavelengths...
    2025/06/02 18:19:45:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/06/02 18:19:45:   Calculating absorption coefficients of liquid water and ice...
    2025/06/02 18:19:45:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/06/02 18:19:46:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/06/02 18:19:47:   Performing first guess liquid water retrieval based on the NDWI...
    2025/06/02 18:19:47:   Performing first guess ice retrieval based on the NDSI...
    2025/06/02 18:19:47:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/06/02 18:19:47:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/06/02 18:19:47:   Preparing segmented SWIR L1B data cube...
    2025/06/02 18:19:47:   Performing 3 phases of water retrieval...
    2025/06/02 18:19:47:   Setting up multiprocessing...
    2025/06/02 18:19:47:   Multiprocessing on 16 cpu's
    2025/06/02 18:19:47:   Preparing optimal estimation input...
    2025/06/02 18:19:47:   Optimization...
    2025/06/02 18:19:49:   Done!
    2025/06/02 18:19:49:   Runtime: 2.13 s
    2025/06/02 18:19:49:   Smoothing segmented CWV retrieval map...
    2025/06/02 18:19:49:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/06/02 18:19:49:   Starting surface reflectance retrieval...
    2025/06/02 18:19:49:   Calculating surface reflectance for vnir detector...
    2025/06/02 18:19:51:   Calculating surface reflectance for swir detector...
    2025/06/02 18:19:53:   Smoothing segmented liquid water and ice maps...
    2025/06/02 18:19:53:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/06/02 18:19:53:   Joining results of atmospheric correction.
    2025/06/02 18:19:53:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/06/02 18:19:53:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:53:   Percentage of defective pixels: 0.49
    2025/06/02 18:19:53:   Percentage of pixels with a defect in any band: 35.60
    2025/06/02 18:19:53:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/06/02 18:19:53:   Percentage of defective pixels: 0.50
    2025/06/02 18:19:53:   Percentage of pixels with a defect in any band: 44.50
    2025/06/02 18:19:53:   Starting orthorectification...
    2025/06/02 18:19:53:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/06/02 18:19:53:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:19:54:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:19:54:   Merging VNIR and SWIR data...
    2025/06/02 18:19:54:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:19:55:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:19:55:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:19:55:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:19:55:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:19:55:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:19:55:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:19:56:   Generating L2A metadata...
    2025/06/02 18:19:56:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    2025/06/02 18:19:57:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/06/02 18:19:57:   L2A product successfully written!
    2025/06/02 18:19:57:   Total runtime of the processing chain: 0:00:37.231981

##### Captured stderr call

    2025/06/02 18:19:20:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 18:19:22:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.6% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    	progress: |=======-------------------------------------------| 14.5% Complete  => 0:00:00
    	progress: |=========-----------------------------------------| 18.7% Complete  => 0:00:00
    	progress: |==============------------------------------------| 27.7% Complete  => 0:00:00
    	progress: |=========================-------------------------| 50.0% Complete  => 0:00:00
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:01
    	progress: |=================================-----------------| 65.7% Complete  => 0:00:01
    	progress: |=======================================-----------| 77.1% Complete  => 0:00:01
    	progress: |=================================================-| 97.6% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/06/02 18:19:53:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:19:53:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/06/02 18:19:57:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/06/02 18:19:57:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/06/02 18:19:57:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:08.549218

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:04.183582

Started | 2025-06-02 18:19:57
Ended | 2025-06-02 18:20:01
Duration | 0:00:04.183582
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.100307

Started | 2025-06-02 18:20:01
Ended | 2025-06-02 18:20:01
Duration | 0:00:00.100307
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:04.018727

Started | 2025-06-02 18:20:01
Ended | 2025-06-02 18:20:05
Duration | 0:00:04.018727
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.171951

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.171951
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003729

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.003729
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002619

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.002619
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001192

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.001192
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.001893

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.001893
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002715

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.002715
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003411

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.003411
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.047535

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.047535
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.001006

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.001006
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001200

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.001200
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.004286

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.004286
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.005065

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.005065
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.402784

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.063291

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.063291
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.029541

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.029541
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.025411

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.025411
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.034351

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.034351
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.034900

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.034900
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.025233

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.025233
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.023136

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:05
Duration | 0:00:00.023136
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.166922

Started | 2025-06-02 18:20:05
Ended | 2025-06-02 18:20:06
Duration | 0:00:00.166922
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:22.298740

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.330434

Started | 2025-06-02 18:20:06
Ended | 2025-06-02 18:20:08
Duration | 0:00:02.330434
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 18:20:06:   Reading metadata for VNIR detector...
    2025/06/02 18:20:06:   Calculating solar irradiance...
    2025/06/02 18:20:06:   Reading metadata for SWIR detector...
    2025/06/02 18:20:07:   Calculating solar irradiance...
    2025/06/02 18:20:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:20:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:20:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:20:07:   Computing VNIR geolayer...
    2025/06/02 18:20:07:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 18:20:06:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/06/02 18:20:08:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/06/02 18:20:08:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.007247

Started | 2025-06-02 18:20:08
Ended | 2025-06-02 18:20:08
Duration | 0:00:00.007247
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:20:08:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010234

Started | 2025-06-02 18:20:08
Ended | 2025-06-02 18:20:08
Duration | 0:00:00.010234
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.970818

Started | 2025-06-02 18:20:08
Ended | 2025-06-02 18:20:10
Duration | 0:00:01.970818
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001196

Started | 2025-06-02 18:20:10
Ended | 2025-06-02 18:20:10
Duration | 0:00:00.001196
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:17.978811

Started | 2025-06-02 18:20:10
Ended | 2025-06-02 18:20:28
Duration | 0:00:17.978811
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:01:59.843681

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:08.711427

Started | 2025-06-02 18:20:28
Ended | 2025-06-02 18:20:37
Duration | 0:00:08.711427
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:20:28:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 18:20:28:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 18:20:28:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 18:20:28:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.2
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release main/v1.2.7
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.335708

Started | 2025-06-02 18:20:37
Ended | 2025-06-02 18:20:37
Duration | 0:00:00.335708
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:20:37:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 18:20:37:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 18:20:37:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 18:20:37:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.000779

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 18:20:37
Ended | 2025-06-02 18:20:37
Duration | 0:00:00.000779
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:15.793256

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-06-02 18:20:37
Ended | 2025-06-02 18:21:53
Duration | 0:01:15.793256
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:20:37:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 18:20:37:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 18:20:37:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 18:20:37:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 18:20:37:   Generating LUT file...
    2025/06/02 18:20:49:   Flightline ID: 20220717T110603Z
    2025/06/02 18:20:49:   no noise path found, proceeding without
    2025/06/02 18:20:49:   Running ISOFIT...
    2025/06/02 18:20:49:   Loading config file: /tmp/tmpqb6bdgy9/workdir/config/isofit_config.json
    2025/06/02 18:20:49:   Checking config sections for configuration issues
    2025/06/02 18:20:49:   Configuration file checks complete, no errors found.
    2025/06/02 18:20:58:   Building first forward model, will generate any necessary LUTs
    2025/06/02 18:20:58:   Loading from wavelength_file: /tmp/tmpqb6bdgy9/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/06/02 18:20:58:   Prebuilt LUT provided
    2025/06/02 18:21:06:   Loading LUT into memory
    2025/06/02 18:21:07:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/06/02 18:21:26:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/06/02 18:21:50:   Inversions complete.  24.07s total, 4.1543 spectra/s, 0.2077 spectra/s/core
    2025/06/02 18:21:50:   ISOFIT finished.
    2025/06/02 18:21:50:   Stopping ray.

##### Captured stderr call

    2025/06/02 18:20:49:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-06-02 18:20:53,381	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-06-02 18:20:54,623	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1748888511.737855     865 chttp2_transport.cc:1182] ipv4:172.17.0.14:64061: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {grpc_status:14, http2_error:2, created_time:"2025-06-02T18:21:51.737835334+00:00"}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000610

Started | 2025-06-02 18:21:53
Ended | 2025-06-02 18:21:53
Duration | 0:00:00.000610
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000466

Started | 2025-06-02 18:21:53
Ended | 2025-06-02 18:21:53
Duration | 0:00:00.000466
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.441400

Started | 2025-06-02 18:21:53
Ended | 2025-06-02 18:21:55
Duration | 0:00:02.441400
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:21:53:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/06/02 18:21:55:   LUT zipfile successfully downloaded.
    2025/06/02 18:21:55:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 18:21:55:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:21.670852

Started | 2025-06-02 18:21:55
Ended | 2025-06-02 18:22:17
Duration | 0:00:21.670852
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:21:55:   Downloading EnPT-internal resources for ISOFIT...
    2025/06/02 18:21:55:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/06/02 18:21:56:   LUT zipfile already downloaded. Proceeding.
    2025/06/02 18:21:56:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/06/02 18:21:56:   Reading Input Data
    2025/06/02 18:21:56:   Reading metadata for VNIR detector...
    2025/06/02 18:21:56:   Calculating solar irradiance...
    2025/06/02 18:21:56:   Reading metadata for SWIR detector...
    2025/06/02 18:21:56:   Calculating solar irradiance...
    2025/06/02 18:21:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:21:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:21:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:21:57:   Computing VNIR geolayer...
    2025/06/02 18:21:57:   Computing SWIR geolayer...
    2025/06/02 18:21:57:   Starting orthorectification...
    2025/06/02 18:21:57:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 18:21:57:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:21:58:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:22:00:   Merging VNIR and SWIR data...
    2025/06/02 18:22:00:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:22:00:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:22:00:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:22:00:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:22:00:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:22:01:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:22:01:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:22:02:   Generating L2A metadata...
    2025/06/02 18:22:03:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmpi_rn87mp/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/06/02 18:22:04:   Generating location file...
    2025/06/02 18:22:04:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmpi_rn87mp/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/06/02 18:22:04:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmpi_rn87mp/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/06/02 18:22:04:   Generating wavelength file...
    2025/06/02 18:22:04:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/06/02 18:22:06:   Generating LUT file...

##### Captured stderr call

    2025/06/02 18:21:56:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.2% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.0% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.0% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.0% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000574

Started | 2025-06-02 18:22:17
Ended | 2025-06-02 18:22:17
Duration | 0:00:00.000574
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000688

Started | 2025-06-02 18:22:17
Ended | 2025-06-02 18:22:17
Duration | 0:00:00.000688
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:10.887921

Started | 2025-06-02 18:22:17
Ended | 2025-06-02 18:22:28
Duration | 0:00:10.887921
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stderr call

    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

## tests/test_l1b_reader.py 10 0:01:49.345583

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:18.621388

Started | 2025-06-02 18:22:28
Ended | 2025-06-02 18:22:46
Duration | 0:00:18.621388
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:22:28:   Reading Input Data
    2025/06/02 18:22:29:   Reading metadata for VNIR detector...
    2025/06/02 18:22:29:   Calculating solar irradiance...
    2025/06/02 18:22:29:   Reading metadata for SWIR detector...
    2025/06/02 18:22:29:   Calculating solar irradiance...
    2025/06/02 18:22:29:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:29:   Reading metadata for VNIR detector...
    2025/06/02 18:22:29:   Calculating solar irradiance...
    2025/06/02 18:22:29:   Reading metadata for SWIR detector...
    2025/06/02 18:22:30:   Calculating solar irradiance...
    2025/06/02 18:22:30:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:30:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:30:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:30:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:30:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:30:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzmgmfum6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:22:31:   L1B product successfully written!
    2025/06/02 18:22:31:   Reading Input Data
    2025/06/02 18:22:31:   Reading metadata for VNIR detector...
    2025/06/02 18:22:31:   Calculating solar irradiance...
    2025/06/02 18:22:31:   Reading metadata for SWIR detector...
    2025/06/02 18:22:31:   Calculating solar irradiance...
    2025/06/02 18:22:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:31:   Reading Input Data
    2025/06/02 18:22:31:   Reading metadata for VNIR detector...
    2025/06/02 18:22:32:   Calculating solar irradiance...
    2025/06/02 18:22:32:   Reading metadata for SWIR detector...
    2025/06/02 18:22:32:   Calculating solar irradiance...
    2025/06/02 18:22:32:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:32:   Reading metadata for VNIR detector...
    2025/06/02 18:22:32:   Calculating solar irradiance...
    2025/06/02 18:22:32:   Reading metadata for SWIR detector...
    2025/06/02 18:22:33:   Calculating solar irradiance...
    2025/06/02 18:22:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:33:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:33:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:33:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:33:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:33:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:33:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:33:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:35:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:22:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpi2pf9ibs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:22:35:   L1B product successfully written!
    2025/06/02 18:22:35:   Reading Input Data
    2025/06/02 18:22:35:   Reading metadata for VNIR detector...
    2025/06/02 18:22:36:   Calculating solar irradiance...
    2025/06/02 18:22:36:   Reading metadata for SWIR detector...
    2025/06/02 18:22:36:   Calculating solar irradiance...
    2025/06/02 18:22:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:36:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:38:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:22:38:   Reading Input Data
    2025/06/02 18:22:38:   Reading metadata for VNIR detector...
    2025/06/02 18:22:38:   Calculating solar irradiance...
    2025/06/02 18:22:38:   Reading metadata for SWIR detector...
    2025/06/02 18:22:39:   Calculating solar irradiance...
    2025/06/02 18:22:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:39:   Reading metadata for VNIR detector...
    2025/06/02 18:22:39:   Calculating solar irradiance...
    2025/06/02 18:22:39:   Reading metadata for SWIR detector...
    2025/06/02 18:22:39:   Calculating solar irradiance...
    2025/06/02 18:22:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:40:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:40:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:40:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpym50z2bi/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:22:40:   L1B product successfully written!
    2025/06/02 18:22:40:   Reading Input Data
    2025/06/02 18:22:40:   Reading metadata for VNIR detector...
    2025/06/02 18:22:41:   Calculating solar irradiance...
    2025/06/02 18:22:41:   Reading metadata for SWIR detector...
    2025/06/02 18:22:41:   Calculating solar irradiance...
    2025/06/02 18:22:41:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:41:   Reading Input Data
    2025/06/02 18:22:41:   Reading metadata for VNIR detector...
    2025/06/02 18:22:42:   Calculating solar irradiance...
    2025/06/02 18:22:42:   Reading metadata for SWIR detector...
    2025/06/02 18:22:42:   Calculating solar irradiance...
    2025/06/02 18:22:42:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:43:   Reading metadata for VNIR detector...
    2025/06/02 18:22:43:   Calculating solar irradiance...
    2025/06/02 18:22:43:   Reading metadata for SWIR detector...
    2025/06/02 18:22:43:   Calculating solar irradiance...
    2025/06/02 18:22:43:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:43:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:43:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:44:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:44:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:22:44:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp2vyonxv8/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:22:45:   L1B product successfully written!
    2025/06/02 18:22:45:   Reading Input Data
    2025/06/02 18:22:45:   Reading metadata for VNIR detector...
    2025/06/02 18:22:45:   Calculating solar irradiance...
    2025/06/02 18:22:45:   Reading metadata for SWIR detector...
    2025/06/02 18:22:45:   Calculating solar irradiance...
    2025/06/02 18:22:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:45:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:46:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:22:30:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:30:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:33:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:22:33:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:22:33:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:22:33:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:22:33:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:22:35:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:35:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:35:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:35:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:35:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:40:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:40:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:40:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:40:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:40:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:40:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:40:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:43:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:44:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:44:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:44:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:44:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:44:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.432601

Started | 2025-06-02 18:22:46
Ended | 2025-06-02 18:23:02
Duration | 0:00:15.432601
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:22:47:   Reading Input Data
    2025/06/02 18:22:47:   Reading metadata for VNIR detector...
    2025/06/02 18:22:47:   Calculating solar irradiance...
    2025/06/02 18:22:47:   Reading metadata for SWIR detector...
    2025/06/02 18:22:48:   Calculating solar irradiance...
    2025/06/02 18:22:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:48:   Reading metadata for VNIR detector...
    2025/06/02 18:22:48:   Calculating solar irradiance...
    2025/06/02 18:22:48:   Reading metadata for SWIR detector...
    2025/06/02 18:22:48:   Calculating solar irradiance...
    2025/06/02 18:22:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:49:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:49:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:49:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:49:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:49:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:49:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp3jqt3_s4/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:22:49:   L1B product successfully written!
    2025/06/02 18:22:49:   Reading Input Data
    2025/06/02 18:22:49:   Reading metadata for VNIR detector...
    2025/06/02 18:22:49:   Calculating solar irradiance...
    2025/06/02 18:22:49:   Reading metadata for SWIR detector...
    2025/06/02 18:22:50:   Calculating solar irradiance...
    2025/06/02 18:22:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:50:   Reading Input Data
    2025/06/02 18:22:50:   Reading metadata for VNIR detector...
    2025/06/02 18:22:50:   Calculating solar irradiance...
    2025/06/02 18:22:50:   Reading metadata for SWIR detector...
    2025/06/02 18:22:50:   Calculating solar irradiance...
    2025/06/02 18:22:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:51:   Reading metadata for VNIR detector...
    2025/06/02 18:22:51:   Calculating solar irradiance...
    2025/06/02 18:22:51:   Reading metadata for SWIR detector...
    2025/06/02 18:22:51:   Calculating solar irradiance...
    2025/06/02 18:22:51:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:51:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:51:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:51:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:51:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:51:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:51:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:22:51:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:52:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:22:53:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4y49wguq/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:22:53:   L1B product successfully written!
    2025/06/02 18:22:53:   Reading Input Data
    2025/06/02 18:22:53:   Reading metadata for VNIR detector...
    2025/06/02 18:22:53:   Calculating solar irradiance...
    2025/06/02 18:22:53:   Reading metadata for SWIR detector...
    2025/06/02 18:22:53:   Calculating solar irradiance...
    2025/06/02 18:22:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:53:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:22:55:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:22:55:   Reading Input Data
    2025/06/02 18:22:55:   Reading metadata for VNIR detector...
    2025/06/02 18:22:55:   Calculating solar irradiance...
    2025/06/02 18:22:55:   Reading metadata for SWIR detector...
    2025/06/02 18:22:55:   Calculating solar irradiance...
    2025/06/02 18:22:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:56:   Reading metadata for VNIR detector...
    2025/06/02 18:22:56:   Calculating solar irradiance...
    2025/06/02 18:22:56:   Reading metadata for SWIR detector...
    2025/06/02 18:22:56:   Calculating solar irradiance...
    2025/06/02 18:22:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:56:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:56:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:56:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkq6zd_kj/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:22:57:   L1B product successfully written!
    2025/06/02 18:22:57:   Reading Input Data
    2025/06/02 18:22:57:   Reading metadata for VNIR detector...
    2025/06/02 18:22:57:   Calculating solar irradiance...
    2025/06/02 18:22:57:   Reading metadata for SWIR detector...
    2025/06/02 18:22:57:   Calculating solar irradiance...
    2025/06/02 18:22:57:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:57:   Reading Input Data
    2025/06/02 18:22:57:   Reading metadata for VNIR detector...
    2025/06/02 18:22:58:   Calculating solar irradiance...
    2025/06/02 18:22:58:   Reading metadata for SWIR detector...
    2025/06/02 18:22:58:   Calculating solar irradiance...
    2025/06/02 18:22:58:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:58:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:58:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:58:   Reading metadata for VNIR detector...
    2025/06/02 18:22:58:   Calculating solar irradiance...
    2025/06/02 18:22:58:   Reading metadata for SWIR detector...
    2025/06/02 18:22:59:   Calculating solar irradiance...
    2025/06/02 18:22:59:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:22:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:22:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:22:59:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:59:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:22:59:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:00:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:00:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzjedj80b/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:00:   L1B product successfully written!
    2025/06/02 18:23:00:   Reading Input Data
    2025/06/02 18:23:00:   Reading metadata for VNIR detector...
    2025/06/02 18:23:00:   Calculating solar irradiance...
    2025/06/02 18:23:00:   Reading metadata for SWIR detector...
    2025/06/02 18:23:01:   Calculating solar irradiance...
    2025/06/02 18:23:01:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:01:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:02:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:22:49:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 18:22:49:   Set the number of line to 50
    2025/06/02 18:22:49:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:22:49:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 18:22:49:   Set the number of line to 50
    2025/06/02 18:22:49:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:49:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:51:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 18:22:51:   Set the number of line to 50
    2025/06/02 18:22:51:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:22:51:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:22:51:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:22:51:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:22:51:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:22:51:   A minimum of 50 lines is required, only 10 were selected
    2025/06/02 18:22:51:   Set the number of line to 50
    2025/06/02 18:22:53:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:53:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:53:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:53:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:53:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:56:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:57:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:22:57:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:22:57:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:22:57:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:22:57:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:22:59:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:22:59:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:00:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:00:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:00:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:00:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:00:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:16.271424

Started | 2025-06-02 18:23:02
Ended | 2025-06-02 18:23:18
Duration | 0:00:16.271424
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:23:03:   Reading Input Data
    2025/06/02 18:23:03:   Reading metadata for VNIR detector...
    2025/06/02 18:23:03:   Calculating solar irradiance...
    2025/06/02 18:23:03:   Reading metadata for SWIR detector...
    2025/06/02 18:23:03:   Calculating solar irradiance...
    2025/06/02 18:23:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:03:   Reading metadata for VNIR detector...
    2025/06/02 18:23:04:   Calculating solar irradiance...
    2025/06/02 18:23:04:   Reading metadata for SWIR detector...
    2025/06/02 18:23:04:   Calculating solar irradiance...
    2025/06/02 18:23:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:04:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:04:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:04:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:04:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:04:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmposaig8xe/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:05:   L1B product successfully written!
    2025/06/02 18:23:05:   Reading Input Data
    2025/06/02 18:23:05:   Reading metadata for VNIR detector...
    2025/06/02 18:23:05:   Calculating solar irradiance...
    2025/06/02 18:23:05:   Reading metadata for SWIR detector...
    2025/06/02 18:23:05:   Calculating solar irradiance...
    2025/06/02 18:23:05:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:05:   Reading Input Data
    2025/06/02 18:23:05:   Reading metadata for VNIR detector...
    2025/06/02 18:23:05:   Calculating solar irradiance...
    2025/06/02 18:23:06:   Reading metadata for SWIR detector...
    2025/06/02 18:23:06:   Calculating solar irradiance...
    2025/06/02 18:23:06:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:06:   Reading metadata for VNIR detector...
    2025/06/02 18:23:06:   Calculating solar irradiance...
    2025/06/02 18:23:06:   Reading metadata for SWIR detector...
    2025/06/02 18:23:07:   Calculating solar irradiance...
    2025/06/02 18:23:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:07:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:07:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:07:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:07:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:07:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:08:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:09:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmps7hm6cm_/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:09:   L1B product successfully written!
    2025/06/02 18:23:09:   Reading Input Data
    2025/06/02 18:23:09:   Reading metadata for VNIR detector...
    2025/06/02 18:23:09:   Calculating solar irradiance...
    2025/06/02 18:23:09:   Reading metadata for SWIR detector...
    2025/06/02 18:23:09:   Calculating solar irradiance...
    2025/06/02 18:23:10:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:10:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:11:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:11:   Reading Input Data
    2025/06/02 18:23:11:   Reading metadata for VNIR detector...
    2025/06/02 18:23:12:   Calculating solar irradiance...
    2025/06/02 18:23:12:   Reading metadata for SWIR detector...
    2025/06/02 18:23:12:   Calculating solar irradiance...
    2025/06/02 18:23:12:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:12:   Reading metadata for VNIR detector...
    2025/06/02 18:23:12:   Calculating solar irradiance...
    2025/06/02 18:23:12:   Reading metadata for SWIR detector...
    2025/06/02 18:23:13:   Calculating solar irradiance...
    2025/06/02 18:23:13:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:13:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:13:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpigl31cag/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:13:   L1B product successfully written!
    2025/06/02 18:23:13:   Reading Input Data
    2025/06/02 18:23:13:   Reading metadata for VNIR detector...
    2025/06/02 18:23:13:   Calculating solar irradiance...
    2025/06/02 18:23:13:   Reading metadata for SWIR detector...
    2025/06/02 18:23:14:   Calculating solar irradiance...
    2025/06/02 18:23:14:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:14:   Reading Input Data
    2025/06/02 18:23:14:   Reading metadata for VNIR detector...
    2025/06/02 18:23:14:   Calculating solar irradiance...
    2025/06/02 18:23:14:   Reading metadata for SWIR detector...
    2025/06/02 18:23:14:   Calculating solar irradiance...
    2025/06/02 18:23:14:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:15:   Reading metadata for VNIR detector...
    2025/06/02 18:23:15:   Calculating solar irradiance...
    2025/06/02 18:23:15:   Reading metadata for SWIR detector...
    2025/06/02 18:23:15:   Calculating solar irradiance...
    2025/06/02 18:23:15:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:15:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:15:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:16:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:16:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:16:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpo623a_hl/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:17:   L1B product successfully written!
    2025/06/02 18:23:17:   Reading Input Data
    2025/06/02 18:23:17:   Reading metadata for VNIR detector...
    2025/06/02 18:23:17:   Calculating solar irradiance...
    2025/06/02 18:23:17:   Reading metadata for SWIR detector...
    2025/06/02 18:23:17:   Calculating solar irradiance...
    2025/06/02 18:23:17:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:17:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:18:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:23:04:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 18:23:04:   Set to the image number of line
    2025/06/02 18:23:04:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:04:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 18:23:04:   Set to the image number of line
    2025/06/02 18:23:04:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:04:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:07:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 18:23:07:   Set to the image number of line
    2025/06/02 18:23:07:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:07:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:07:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:07:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:07:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:07:   n_lines (150) exceeds the total number of line of second image
    2025/06/02 18:23:07:   Set to the image number of line
    2025/06/02 18:23:09:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:09:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:09:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:09:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:09:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:13:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:13:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:15:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:15:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:16:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:16:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:16:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:16:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:16:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:15.755114

Started | 2025-06-02 18:23:18
Ended | 2025-06-02 18:23:34
Duration | 0:00:15.755114
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:23:19:   Reading Input Data
    2025/06/02 18:23:19:   Reading metadata for VNIR detector...
    2025/06/02 18:23:19:   Calculating solar irradiance...
    2025/06/02 18:23:19:   Reading metadata for SWIR detector...
    2025/06/02 18:23:19:   Calculating solar irradiance...
    2025/06/02 18:23:19:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:19:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:20:   Reading metadata for VNIR detector...
    2025/06/02 18:23:20:   Calculating solar irradiance...
    2025/06/02 18:23:20:   Reading metadata for SWIR detector...
    2025/06/02 18:23:20:   Calculating solar irradiance...
    2025/06/02 18:23:20:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:20:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:20:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:20:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:20:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:20:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5evbtaw1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:21:   L1B product successfully written!
    2025/06/02 18:23:21:   Reading Input Data
    2025/06/02 18:23:21:   Reading metadata for VNIR detector...
    2025/06/02 18:23:21:   Calculating solar irradiance...
    2025/06/02 18:23:21:   Reading metadata for SWIR detector...
    2025/06/02 18:23:21:   Calculating solar irradiance...
    2025/06/02 18:23:21:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:21:   Reading Input Data
    2025/06/02 18:23:21:   Reading metadata for VNIR detector...
    2025/06/02 18:23:22:   Calculating solar irradiance...
    2025/06/02 18:23:22:   Reading metadata for SWIR detector...
    2025/06/02 18:23:22:   Calculating solar irradiance...
    2025/06/02 18:23:22:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:22:   Reading metadata for VNIR detector...
    2025/06/02 18:23:22:   Calculating solar irradiance...
    2025/06/02 18:23:22:   Reading metadata for SWIR detector...
    2025/06/02 18:23:23:   Calculating solar irradiance...
    2025/06/02 18:23:23:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:23:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:23:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:23:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:23:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:23:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:24:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:24:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpn9qsuiho/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:25:   L1B product successfully written!
    2025/06/02 18:23:25:   Reading Input Data
    2025/06/02 18:23:25:   Reading metadata for VNIR detector...
    2025/06/02 18:23:25:   Calculating solar irradiance...
    2025/06/02 18:23:25:   Reading metadata for SWIR detector...
    2025/06/02 18:23:25:   Calculating solar irradiance...
    2025/06/02 18:23:25:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:25:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:26:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:27:   Reading Input Data
    2025/06/02 18:23:27:   Reading metadata for VNIR detector...
    2025/06/02 18:23:27:   Calculating solar irradiance...
    2025/06/02 18:23:27:   Reading metadata for SWIR detector...
    2025/06/02 18:23:27:   Calculating solar irradiance...
    2025/06/02 18:23:27:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:28:   Reading metadata for VNIR detector...
    2025/06/02 18:23:28:   Calculating solar irradiance...
    2025/06/02 18:23:28:   Reading metadata for SWIR detector...
    2025/06/02 18:23:28:   Calculating solar irradiance...
    2025/06/02 18:23:28:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:28:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:28:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:28:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpt0pn_gai/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:29:   L1B product successfully written!
    2025/06/02 18:23:29:   Reading Input Data
    2025/06/02 18:23:29:   Reading metadata for VNIR detector...
    2025/06/02 18:23:29:   Calculating solar irradiance...
    2025/06/02 18:23:29:   Reading metadata for SWIR detector...
    2025/06/02 18:23:29:   Calculating solar irradiance...
    2025/06/02 18:23:29:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:29:   Reading Input Data
    2025/06/02 18:23:30:   Reading metadata for VNIR detector...
    2025/06/02 18:23:30:   Calculating solar irradiance...
    2025/06/02 18:23:30:   Reading metadata for SWIR detector...
    2025/06/02 18:23:30:   Calculating solar irradiance...
    2025/06/02 18:23:30:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:30:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:30:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:30:   Reading metadata for VNIR detector...
    2025/06/02 18:23:30:   Calculating solar irradiance...
    2025/06/02 18:23:31:   Reading metadata for SWIR detector...
    2025/06/02 18:23:31:   Calculating solar irradiance...
    2025/06/02 18:23:31:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:31:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:31:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:31:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:32:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:32:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4tuu17nb/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:32:   L1B product successfully written!
    2025/06/02 18:23:32:   Reading Input Data
    2025/06/02 18:23:32:   Reading metadata for VNIR detector...
    2025/06/02 18:23:33:   Calculating solar irradiance...
    2025/06/02 18:23:33:   Reading metadata for SWIR detector...
    2025/06/02 18:23:33:   Calculating solar irradiance...
    2025/06/02 18:23:33:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:33:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:34:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:23:20:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:20:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:23:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:23:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:23:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:23:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:23:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:24:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:24:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:24:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:24:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:24:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:28:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:28:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:29:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:29:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:31:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:31:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:32:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:32:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:32:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:32:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:32:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:17.474922

Started | 2025-06-02 18:23:34
Ended | 2025-06-02 18:23:51
Duration | 0:00:17.474922
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:23:35:   Reading Input Data
    2025/06/02 18:23:35:   Reading metadata for VNIR detector...
    2025/06/02 18:23:35:   Calculating solar irradiance...
    2025/06/02 18:23:35:   Reading metadata for SWIR detector...
    2025/06/02 18:23:35:   Calculating solar irradiance...
    2025/06/02 18:23:35:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:35:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:35:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:35:   Reading metadata for VNIR detector...
    2025/06/02 18:23:36:   Calculating solar irradiance...
    2025/06/02 18:23:36:   Reading metadata for SWIR detector...
    2025/06/02 18:23:36:   Calculating solar irradiance...
    2025/06/02 18:23:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:36:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:36:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:36:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:36:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:36:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:36:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmphbkhqq6n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:37:   L1B product successfully written!
    2025/06/02 18:23:37:   Reading Input Data
    2025/06/02 18:23:37:   Reading metadata for VNIR detector...
    2025/06/02 18:23:37:   Calculating solar irradiance...
    2025/06/02 18:23:37:   Reading metadata for SWIR detector...
    2025/06/02 18:23:37:   Calculating solar irradiance...
    2025/06/02 18:23:37:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:37:   Reading Input Data
    2025/06/02 18:23:37:   Reading metadata for VNIR detector...
    2025/06/02 18:23:38:   Calculating solar irradiance...
    2025/06/02 18:23:38:   Reading metadata for SWIR detector...
    2025/06/02 18:23:38:   Calculating solar irradiance...
    2025/06/02 18:23:38:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:38:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:38:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:38:   Reading metadata for VNIR detector...
    2025/06/02 18:23:38:   Calculating solar irradiance...
    2025/06/02 18:23:38:   Reading metadata for SWIR detector...
    2025/06/02 18:23:39:   Calculating solar irradiance...
    2025/06/02 18:23:39:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:39:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:39:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:39:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:39:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:39:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:42:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:42:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpnwu219k3/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:42:   L1B product successfully written!
    2025/06/02 18:23:42:   Reading Input Data
    2025/06/02 18:23:42:   Reading metadata for VNIR detector...
    2025/06/02 18:23:43:   Calculating solar irradiance...
    2025/06/02 18:23:43:   Reading metadata for SWIR detector...
    2025/06/02 18:23:43:   Calculating solar irradiance...
    2025/06/02 18:23:43:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:43:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:45:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:45:   Reading Input Data
    2025/06/02 18:23:45:   Reading metadata for VNIR detector...
    2025/06/02 18:23:45:   Calculating solar irradiance...
    2025/06/02 18:23:45:   Reading metadata for SWIR detector...
    2025/06/02 18:23:45:   Calculating solar irradiance...
    2025/06/02 18:23:45:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:45:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:45:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:46:   Reading metadata for VNIR detector...
    2025/06/02 18:23:46:   Calculating solar irradiance...
    2025/06/02 18:23:46:   Reading metadata for SWIR detector...
    2025/06/02 18:23:46:   Calculating solar irradiance...
    2025/06/02 18:23:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:46:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:46:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:46:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpszzeuqd0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:47:   L1B product successfully written!
    2025/06/02 18:23:47:   Reading Input Data
    2025/06/02 18:23:47:   Reading metadata for VNIR detector...
    2025/06/02 18:23:47:   Calculating solar irradiance...
    2025/06/02 18:23:47:   Reading metadata for SWIR detector...
    2025/06/02 18:23:47:   Calculating solar irradiance...
    2025/06/02 18:23:47:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:47:   Reading Input Data
    2025/06/02 18:23:47:   Reading metadata for VNIR detector...
    2025/06/02 18:23:47:   Calculating solar irradiance...
    2025/06/02 18:23:47:   Reading metadata for SWIR detector...
    2025/06/02 18:23:48:   Calculating solar irradiance...
    2025/06/02 18:23:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:48:   Reading metadata for VNIR detector...
    2025/06/02 18:23:48:   Calculating solar irradiance...
    2025/06/02 18:23:48:   Reading metadata for SWIR detector...
    2025/06/02 18:23:48:   Calculating solar irradiance...
    2025/06/02 18:23:49:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:49:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:49:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:49:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:49:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:23:49:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:49:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:50:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa_u8xocc/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:23:50:   L1B product successfully written!
    2025/06/02 18:23:50:   Reading Input Data
    2025/06/02 18:23:50:   Reading metadata for VNIR detector...
    2025/06/02 18:23:50:   Calculating solar irradiance...
    2025/06/02 18:23:50:   Reading metadata for SWIR detector...
    2025/06/02 18:23:50:   Calculating solar irradiance...
    2025/06/02 18:23:50:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:50:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:51:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:23:36:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:36:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:36:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:36:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:36:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:36:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:37:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:37:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:37:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:37:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:39:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:39:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:39:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:39:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:39:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:42:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:42:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:42:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:42:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:42:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:46:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:46:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:46:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:46:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:46:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:46:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:49:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:49:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:23:50:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:50:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:50:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:50:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:50:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:16.323221

Started | 2025-06-02 18:23:51
Ended | 2025-06-02 18:24:08
Duration | 0:00:16.323221
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:23:52:   Reading Input Data
    2025/06/02 18:23:52:   Reading metadata for VNIR detector...
    2025/06/02 18:23:52:   Calculating solar irradiance...
    2025/06/02 18:23:52:   Reading metadata for SWIR detector...
    2025/06/02 18:23:53:   Calculating solar irradiance...
    2025/06/02 18:23:53:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:53:   Reading metadata for VNIR detector...
    2025/06/02 18:23:53:   Calculating solar irradiance...
    2025/06/02 18:23:53:   Reading metadata for SWIR detector...
    2025/06/02 18:23:53:   Calculating solar irradiance...
    2025/06/02 18:23:54:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:54:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:54:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:54:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:54:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:54:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpaytnnhp2/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:54:   L1B product successfully written!
    2025/06/02 18:23:54:   Reading Input Data
    2025/06/02 18:23:54:   Reading metadata for VNIR detector...
    2025/06/02 18:23:55:   Calculating solar irradiance...
    2025/06/02 18:23:55:   Reading metadata for SWIR detector...
    2025/06/02 18:23:55:   Calculating solar irradiance...
    2025/06/02 18:23:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:55:   Reading Input Data
    2025/06/02 18:23:55:   Reading metadata for VNIR detector...
    2025/06/02 18:23:55:   Calculating solar irradiance...
    2025/06/02 18:23:55:   Reading metadata for SWIR detector...
    2025/06/02 18:23:55:   Calculating solar irradiance...
    2025/06/02 18:23:55:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:56:   Reading metadata for VNIR detector...
    2025/06/02 18:23:56:   Calculating solar irradiance...
    2025/06/02 18:23:56:   Reading metadata for SWIR detector...
    2025/06/02 18:23:56:   Calculating solar irradiance...
    2025/06/02 18:23:56:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:23:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:23:57:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:57:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:57:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:57:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/06/02 18:23:57:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:23:58:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:23:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpakj4yxwc/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:23:59:   L1B product successfully written!
    2025/06/02 18:23:59:   Reading Input Data
    2025/06/02 18:23:59:   Reading metadata for VNIR detector...
    2025/06/02 18:23:59:   Calculating solar irradiance...
    2025/06/02 18:23:59:   Reading metadata for SWIR detector...
    2025/06/02 18:23:59:   Calculating solar irradiance...
    2025/06/02 18:23:59:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:23:59:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:01:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:24:01:   Reading Input Data
    2025/06/02 18:24:01:   Reading metadata for VNIR detector...
    2025/06/02 18:24:01:   Calculating solar irradiance...
    2025/06/02 18:24:01:   Reading metadata for SWIR detector...
    2025/06/02 18:24:02:   Calculating solar irradiance...
    2025/06/02 18:24:02:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:02:   Reading metadata for VNIR detector...
    2025/06/02 18:24:02:   Calculating solar irradiance...
    2025/06/02 18:24:02:   Reading metadata for SWIR detector...
    2025/06/02 18:24:02:   Calculating solar irradiance...
    2025/06/02 18:24:03:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:03:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:03:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:03:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:24:03:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:24:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpw7a4vh6c/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:24:03:   L1B product successfully written!
    2025/06/02 18:24:03:   Reading Input Data
    2025/06/02 18:24:03:   Reading metadata for VNIR detector...
    2025/06/02 18:24:03:   Calculating solar irradiance...
    2025/06/02 18:24:03:   Reading metadata for SWIR detector...
    2025/06/02 18:24:03:   Calculating solar irradiance...
    2025/06/02 18:24:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:04:   Reading Input Data
    2025/06/02 18:24:04:   Reading metadata for VNIR detector...
    2025/06/02 18:24:04:   Calculating solar irradiance...
    2025/06/02 18:24:04:   Reading metadata for SWIR detector...
    2025/06/02 18:24:04:   Calculating solar irradiance...
    2025/06/02 18:24:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:04:   Reading metadata for VNIR detector...
    2025/06/02 18:24:05:   Calculating solar irradiance...
    2025/06/02 18:24:05:   Reading metadata for SWIR detector...
    2025/06/02 18:24:05:   Calculating solar irradiance...
    2025/06/02 18:24:05:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:05:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:24:05:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/06/02 18:24:05:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:06:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:24:06:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp0_rlm7ga/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/06/02 18:24:06:   L1B product successfully written!
    2025/06/02 18:24:06:   Reading Input Data
    2025/06/02 18:24:06:   Reading metadata for VNIR detector...
    2025/06/02 18:24:06:   Calculating solar irradiance...
    2025/06/02 18:24:06:   Reading metadata for SWIR detector...
    2025/06/02 18:24:07:   Calculating solar irradiance...
    2025/06/02 18:24:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:07:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:08:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/06/02 18:23:54:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:54:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:23:57:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/06/02 18:23:57:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/06/02 18:23:57:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/06/02 18:23:57:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/06/02 18:23:57:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/06/02 18:23:58:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:23:58:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:23:58:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:23:58:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:23:58:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:24:03:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:24:03:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:24:03:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:24:03:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:24:03:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:24:03:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:24:03:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/06/02 18:24:05:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:24:05:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/06/02 18:24:06:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:24:06:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:24:06:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:24:06:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:24:06:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.312375

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-06-02 18:24:08
Ended | 2025-06-02 18:24:10
Duration | 0:00:02.312375
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:08:   Reading Input Data
    2025/06/02 18:24:08:   Reading metadata for VNIR detector...
    2025/06/02 18:24:09:   Calculating solar irradiance...
    2025/06/02 18:24:09:   Reading metadata for SWIR detector...
    2025/06/02 18:24:09:   Calculating solar irradiance...
    2025/06/02 18:24:09:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:09:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:09:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:09:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp1kd_fwk7/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:24:09:   L1B product successfully written!
    2025/06/02 18:24:09:   Reading Input Data
    2025/06/02 18:24:09:   Reading metadata for VNIR detector...
    2025/06/02 18:24:10:   Calculating solar irradiance...
    2025/06/02 18:24:10:   Reading metadata for SWIR detector...
    2025/06/02 18:24:10:   Calculating solar irradiance...
    2025/06/02 18:24:10:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 18:24:09:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:24:09:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:24:09:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:24:09:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:24:09:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.049114

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-06-02 18:24:10
Ended | 2025-06-02 18:24:13
Duration | 0:00:03.049114
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:11:   Reading Input Data
    2025/06/02 18:24:11:   Reading metadata for VNIR detector...
    2025/06/02 18:24:11:   Calculating solar irradiance...
    2025/06/02 18:24:11:   Reading metadata for SWIR detector...
    2025/06/02 18:24:11:   Calculating solar irradiance...
    2025/06/02 18:24:11:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:11:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:12:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:24:12:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpic9soaah/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/06/02 18:24:12:   L1B product successfully written!
    2025/06/02 18:24:12:   Reading Input Data
    2025/06/02 18:24:13:   Reading metadata for VNIR detector...
    2025/06/02 18:24:13:   Calculating solar irradiance...
    2025/06/02 18:24:13:   Reading metadata for SWIR detector...
    2025/06/02 18:24:13:   Calculating solar irradiance...
    2025/06/02 18:24:13:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/06/02 18:24:12:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/06/02 18:24:12:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/06/02 18:24:12:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/06/02 18:24:12:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/06/02 18:24:12:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.353702

Started | 2025-06-02 18:24:13
Ended | 2025-06-02 18:24:15
Duration | 0:00:02.353702
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:13:   Reading Input Data
    2025/06/02 18:24:13:   Reading metadata for VNIR detector...
    2025/06/02 18:24:14:   Calculating solar irradiance...
    2025/06/02 18:24:14:   Reading metadata for SWIR detector...
    2025/06/02 18:24:14:   Calculating solar irradiance...
    2025/06/02 18:24:14:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:15:   Computing VNIR geolayer...
    2025/06/02 18:24:15:   Computing SWIR geolayer...
    2025/06/02 18:24:15:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/06/02 18:24:15:   L1B product successfully written!

##### Captured stderr call

    2025/06/02 18:24:13:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.751723

Started | 2025-06-02 18:24:15
Ended | 2025-06-02 18:24:17
Duration | 0:00:01.751723
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:16:   Reading Input Data
    2025/06/02 18:24:16:   Reading metadata for VNIR detector...
    2025/06/02 18:24:16:   Calculating solar irradiance...
    2025/06/02 18:24:16:   Reading metadata for SWIR detector...
    2025/06/02 18:24:16:   Calculating solar irradiance...
    2025/06/02 18:24:16:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:17:   Computing VNIR geolayer...
    2025/06/02 18:24:17:   Computing SWIR geolayer...

##### Captured stderr call

    2025/06/02 18:24:16:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:25.434783

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.507049

Started | 2025-06-02 18:24:17
Ended | 2025-06-02 18:24:23
Duration | 0:00:05.507049
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:18:   Reading Input Data
    2025/06/02 18:24:18:   Reading metadata for VNIR detector...
    2025/06/02 18:24:18:   Calculating solar irradiance...
    2025/06/02 18:24:18:   Reading metadata for SWIR detector...
    2025/06/02 18:24:18:   Calculating solar irradiance...
    2025/06/02 18:24:18:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:18:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:18:   Starting orthorectification...
    2025/06/02 18:24:18:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/06/02 18:24:18:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:19:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:21:   Merging VNIR and SWIR data...
    2025/06/02 18:24:21:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:24:21:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:24:22:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:05.103729

Started | 2025-06-02 18:24:23
Ended | 2025-06-02 18:24:28
Duration | 0:00:05.103729
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:23:   Reading Input Data
    2025/06/02 18:24:23:   Reading metadata for VNIR detector...
    2025/06/02 18:24:23:   Calculating solar irradiance...
    2025/06/02 18:24:23:   Reading metadata for SWIR detector...
    2025/06/02 18:24:24:   Calculating solar irradiance...
    2025/06/02 18:24:24:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:24:   Starting orthorectification...
    2025/06/02 18:24:24:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/06/02 18:24:24:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:25:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:26:   Merging VNIR and SWIR data...
    2025/06/02 18:24:26:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:24:26:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:24:27:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.799189

Started | 2025-06-02 18:24:28
Ended | 2025-06-02 18:24:35
Duration | 0:00:06.799189
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:28:   Reading Input Data
    2025/06/02 18:24:28:   Reading metadata for VNIR detector...
    2025/06/02 18:24:28:   Calculating solar irradiance...
    2025/06/02 18:24:28:   Reading metadata for SWIR detector...
    2025/06/02 18:24:29:   Calculating solar irradiance...
    2025/06/02 18:24:29:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:29:   Computing VNIR geolayer...
    2025/06/02 18:24:30:   Computing SWIR geolayer...
    2025/06/02 18:24:30:   Starting orthorectification...
    2025/06/02 18:24:30:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/06/02 18:24:30:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:31:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:32:   Merging VNIR and SWIR data...
    2025/06/02 18:24:32:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:24:32:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:24:32:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:24:33:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:24:33:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:24:33:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:24:33:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:24:34:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 18:24:28:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:07.997407

Started | 2025-06-02 18:24:35
Ended | 2025-06-02 18:24:43
Duration | 0:00:07.997407
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:35:   Reading Input Data
    2025/06/02 18:24:35:   Reading metadata for VNIR detector...
    2025/06/02 18:24:35:   Calculating solar irradiance...
    2025/06/02 18:24:35:   Reading metadata for SWIR detector...
    2025/06/02 18:24:35:   Calculating solar irradiance...
    2025/06/02 18:24:36:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:36:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:36:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:36:   Computing VNIR geolayer...
    2025/06/02 18:24:36:   Computing SWIR geolayer...
    2025/06/02 18:24:36:   Starting orthorectification...
    2025/06/02 18:24:36:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/06/02 18:24:36:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:37:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/06/02 18:24:39:   Merging VNIR and SWIR data...
    2025/06/02 18:24:39:   Orthorectifying 'mask_landwater' attribute...
    2025/06/02 18:24:39:   Orthorectifying 'mask_clouds' attribute...
    2025/06/02 18:24:39:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/06/02 18:24:39:   Orthorectifying 'mask_haze' attribute...
    2025/06/02 18:24:40:   Orthorectifying 'mask_snow' attribute...
    2025/06/02 18:24:40:   Orthorectifying 'mask_cirrus' attribute...
    2025/06/02 18:24:41:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/06/02 18:24:41:   Generating L2A metadata...

##### Captured stderr call

    2025/06/02 18:24:35:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.005847

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.005847
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.004769

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.004769
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.003786

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.003786
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.003483

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.003483
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.003433

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.003433
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.006091

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:43
Duration | 0:00:00.006091
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.414673

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.414673

Started | 2025-06-02 18:24:43
Ended | 2025-06-02 18:24:47
Duration | 0:00:04.414673
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmpgimqzfr6
    2025/06/02 18:24:43:   Reading Input Data
    2025/06/02 18:24:43:   Reading metadata for VNIR detector...
    2025/06/02 18:24:43:   Calculating solar irradiance...
    2025/06/02 18:24:43:   Reading metadata for SWIR detector...
    2025/06/02 18:24:44:   Calculating solar irradiance...
    2025/06/02 18:24:44:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:44:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:45:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:24:45:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 18:24:45:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmpdzsub2v5
    2025/06/02 18:24:45:   Reading Input Data
    2025/06/02 18:24:45:   Reading metadata for VNIR detector...
    2025/06/02 18:24:45:   Calculating solar irradiance...
    2025/06/02 18:24:45:   Reading metadata for SWIR detector...
    2025/06/02 18:24:46:   Calculating solar irradiance...
    2025/06/02 18:24:46:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:46:   Computing SNR from VNIR TOA radiance.
    2025/06/02 18:24:47:   Computing SNR from SWIR TOA radiance.
    2025/06/02 18:24:47:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/06/02 18:24:47:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:15.775685

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:15.775685

Started | 2025-06-02 18:24:47
Ended | 2025-06-02 18:25:03
Duration | 0:00:15.775685
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:24:47:   Reading Input Data
    2025/06/02 18:24:47:   Reading metadata for VNIR detector...
    2025/06/02 18:24:48:   Calculating solar irradiance...
    2025/06/02 18:24:48:   Reading metadata for SWIR detector...
    2025/06/02 18:24:48:   Calculating solar irradiance...
    2025/06/02 18:24:48:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:24:48:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:24:48:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:24:49:   Computing VNIR geolayer...
    2025/06/02 18:24:49:   Computing SWIR geolayer...
    2025/06/02 18:24:49:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/06/02 18:24:49:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/06/02 18:24:50:   Preparing reference image for co-registration.
    2025/06/02 18:24:50:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/06/02 18:25:02:   Generating misregistration array.
    interpolation runtime: 0.20s
    interpolation runtime: 0.17s
    2025/06/02 18:25:02:   Transforming spatial optimization results back to sensor geometry.
    2025/06/02 18:25:03:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/06/02 18:24:47:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/06/02 18:24:49:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.2% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.3% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.8% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.2% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.2% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.4% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.4% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.3% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.3% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.2% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.2% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.3% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.1% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.4% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.3% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.5% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.5% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.3% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.3% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.4% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.6% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.0% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.0% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.4% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.2% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.1% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.3% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.2% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.3% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.2% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.3% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.2% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.2% Complete  => 0:00:00
    Warping progress     |==================================================| 99.2% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:10
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:10
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:10
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:10
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:10
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:10
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:10
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:11
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:11
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:11
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:11
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:11
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:11
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:11
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:11
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:11
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:11
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:11
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:11
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:11
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:11
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:11
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:11
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:11
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:11
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:11
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:11
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:11
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:11
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:11
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:11
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:11
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:11
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:11
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:11
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:11
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:11
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:11
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:11
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:11
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:11
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:11
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:11
    	progress: |============================----------------------| 55.3% Complete  => 0:00:11
    	progress: |============================----------------------| 55.9% Complete  => 0:00:11
    	progress: |============================----------------------| 56.5% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:11
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:11
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:11
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:11
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:11
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:11
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:11
    	progress: |================================------------------| 63.4% Complete  => 0:00:11
    	progress: |================================------------------| 64.0% Complete  => 0:00:11
    	progress: |================================------------------| 64.6% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:11
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:11
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:11
    	progress: |==================================----------------| 67.1% Complete  => 0:00:11
    	progress: |==================================----------------| 67.7% Complete  => 0:00:11
    	progress: |==================================----------------| 68.3% Complete  => 0:00:11
    	progress: |==================================----------------| 68.9% Complete  => 0:00:11
    	progress: |===================================---------------| 69.6% Complete  => 0:00:11
    	progress: |===================================---------------| 70.2% Complete  => 0:00:11
    	progress: |===================================---------------| 70.8% Complete  => 0:00:11
    	progress: |====================================--------------| 71.4% Complete  => 0:00:11
    	progress: |====================================--------------| 72.0% Complete  => 0:00:11
    	progress: |====================================--------------| 72.7% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:11
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:11
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:11
    	progress: |======================================------------| 75.2% Complete  => 0:00:11
    	progress: |======================================------------| 75.8% Complete  => 0:00:11
    	progress: |======================================------------| 76.4% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:11
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:11
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:11
    	progress: |========================================----------| 79.5% Complete  => 0:00:11
    	progress: |========================================----------| 80.1% Complete  => 0:00:11
    	progress: |========================================----------| 80.7% Complete  => 0:00:11
    	progress: |=========================================---------| 81.4% Complete  => 0:00:11
    	progress: |=========================================---------| 82.0% Complete  => 0:00:11
    	progress: |=========================================---------| 82.6% Complete  => 0:00:11
    	progress: |==========================================--------| 83.2% Complete  => 0:00:11
    	progress: |==========================================--------| 83.9% Complete  => 0:00:11
    	progress: |==========================================--------| 84.5% Complete  => 0:00:11
    	progress: |===========================================-------| 85.1% Complete  => 0:00:11
    	progress: |===========================================-------| 85.7% Complete  => 0:00:11
    	progress: |===========================================-------| 86.3% Complete  => 0:00:11
    	progress: |===========================================-------| 87.0% Complete  => 0:00:11
    	progress: |============================================------| 87.6% Complete  => 0:00:11
    	progress: |============================================------| 88.2% Complete  => 0:00:11
    	progress: |============================================------| 88.8% Complete  => 0:00:11
    	progress: |=============================================-----| 89.4% Complete  => 0:00:11
    	progress: |=============================================-----| 90.1% Complete  => 0:00:11
    	progress: |=============================================-----| 90.7% Complete  => 0:00:11
    	progress: |==============================================----| 91.3% Complete  => 0:00:11
    	progress: |==============================================----| 91.9% Complete  => 0:00:11
    	progress: |==============================================----| 92.5% Complete  => 0:00:11
    	progress: |===============================================---| 93.2% Complete  => 0:00:11
    	progress: |===============================================---| 93.8% Complete  => 0:00:11
    	progress: |===============================================---| 94.4% Complete  => 0:00:11
    	progress: |================================================--| 95.0% Complete  => 0:00:11
    	progress: |================================================--| 95.7% Complete  => 0:00:11
    	progress: |================================================--| 96.3% Complete  => 0:00:11
    	progress: |================================================--| 96.9% Complete  => 0:00:11
    	progress: |=================================================-| 97.5% Complete  => 0:00:11
    	progress: |=================================================-| 98.1% Complete  => 0:00:11
    	progress: |=================================================-| 98.8% Complete  => 0:00:11
    	progress: |==================================================| 99.4% Complete  => 0:00:11
    	progress: |==================================================| 100.0% Complete  => 0:00:11

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:35.285359

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.748072

Started | 2025-06-02 18:25:03
Ended | 2025-06-02 18:25:05
Duration | 0:00:01.748072
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:25:03:   Reading Input Data
    2025/06/02 18:25:03:   Reading metadata for VNIR detector...
    2025/06/02 18:25:03:   Calculating solar irradiance...
    2025/06/02 18:25:03:   Reading metadata for SWIR detector...
    2025/06/02 18:25:04:   Calculating solar irradiance...
    2025/06/02 18:25:04:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:25:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:25:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.284811

Started | 2025-06-02 18:25:05
Ended | 2025-06-02 18:25:06
Duration | 0:00:01.284811
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/06/02 18:25:05:   Reading Input Data
    2025/06/02 18:25:05:   Reading metadata for VNIR detector...
    2025/06/02 18:25:05:   Calculating solar irradiance...
    2025/06/02 18:25:05:   Reading metadata for SWIR detector...
    2025/06/02 18:25:05:   Calculating solar irradiance...
    2025/06/02 18:25:05:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:25:06:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:25:06:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.374957

Started | 2025-06-02 18:25:06
Ended | 2025-06-02 18:25:08
Duration | 0:00:02.374957
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/06/02 18:25:06:   Reading Input Data
    2025/06/02 18:25:06:   Reading metadata for VNIR detector...
    2025/06/02 18:25:06:   Calculating solar irradiance...
    2025/06/02 18:25:06:   Reading metadata for SWIR detector...
    2025/06/02 18:25:07:   Calculating solar irradiance...
    2025/06/02 18:25:07:   Reading image masks in VNIR sensor geometry.
    2025/06/02 18:25:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/06/02 18:25:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/06/02 18:25:07:   Computing VNIR geolayer...
    2025/06/02 18:25:08:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/06/02 18:25:06:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.393218

Started | 2025-06-02 18:25:08
Ended | 2025-06-02 18:25:09
Duration | 0:00:00.393218
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.537264

Started | 2025-06-02 18:25:09
Ended | 2025-06-02 18:25:09
Duration | 0:00:00.537264
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.373565

Started | 2025-06-02 18:25:09
Ended | 2025-06-02 18:25:10
Duration | 0:00:00.373565
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:21.328591

Started | 2025-06-02 18:25:10
Ended | 2025-06-02 18:25:31
Duration | 0:00:21.328591
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.441934

Started | 2025-06-02 18:25:31
Ended | 2025-06-02 18:25:31
Duration | 0:00:00.441934
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.404597

Started | 2025-06-02 18:25:31
Ended | 2025-06-02 18:25:32
Duration | 0:00:00.404597
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.004764

Started | 2025-06-02 18:25:32
Ended | 2025-06-02 18:25:32
Duration | 0:00:00.004764
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002773

Started | 2025-06-02 18:25:32
Ended | 2025-06-02 18:25:32
Duration | 0:00:00.002773
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.003006

Started | 2025-06-02 18:25:32
Ended | 2025-06-02 18:25:32
Duration | 0:00:00.003006
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:01.913438

Started | 2025-06-02 18:25:32
Ended | 2025-06-02 18:25:34
Duration | 0:00:01.913438
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.484744

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-06-02 18:25:34
Ended | 2025-06-02 18:25:34
Duration | 0:00:00.484744
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.130811

Started | 2025-06-02 18:25:34
Ended | 2025-06-02 18:25:36
Duration | 0:00:02.130811
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.435704

Started | 2025-06-02 18:25:36
Ended | 2025-06-02 18:25:38
Duration | 0:00:01.435704
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.423112

Started | 2025-06-02 18:25:38
Ended | 2025-06-02 18:25:38
Duration | 0:00:00.423112
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.005701

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.005701

Started | 2025-06-02 18:25:38
Ended | 2025-06-02 18:25:38
Duration | 0:00:00.005701
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown